@@ -89,6 +89,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_DirList.currentIndexChanged.connect(self.selection_directory)
         self.ui_fs_serverlist.hide()
         self.ui_fs_serverlist.clicked.connect(self.fs_select_other)
+        # ToDo check order of calls
+        self.active_url = self.fs_url
+        self.select_fs()
 
     def configure(self):
         if isinstance(self.file_pattern, list):
@@ -196,7 +199,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.authentification = "{}:{}@".format(parseresult.username,  parseresult.password)
             self.active_url = self.active_url.replace(self.authentification, u"")
         self.browse_folder()
-        self.selection_directory()
 
     def action_buttons(self):
         """
@@ -250,7 +252,17 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         # on clearing ui_DirList also index changes and makes an additional call of that method
         if self.ui_DirList.count() > 0:
             try:
-                for item in sorted(self.fs.listdir(_sel_dir)):
+                names = self.fs.listdir(_sel_dir)
+                # cleanup not valid names
+                # ToDo improve for other cases, e.g. fs.errors.PermissionDenied
+                for item in names:
+                    _item = fs.path.combine(_sel_dir, item)
+                    try:
+                        self.fs.isdir(_item)
+                    except TypeError:
+                        names.remove(item)
+                        logging.error("item name %s removed from list" % item)
+                for item in sorted(names):
                     _item = fs.path.combine(_sel_dir, item)
                     try:
                         self.selected_file_pattern = get_extension_from_string(file_type)
